==> vue-code-generator-plugin-test-0.0.2.tgz: package/es/generator/plugins/component/vue3/lifeCycles.js <==
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _extends from "@babel/runtime/helpers/extends";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { ChunkType } from '@alilc/lowcode-code-generator';
import _ from 'lodash';
import { VUE_CHUNK_NAME } from './const';
var pluginFactory = function pluginFactory(config) {
  var cfg = _extends({
    fileType: 'vue'
  }, config);
  var plugin = /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(pre) {
      var next, ir, createLifeCyclesContent, createVueImport;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            next = _extends({}, pre);
            ir = next.ir;
            if (ir.lifeCycles) {
              _context.next = 4;
              break;
            }
            return _context.abrupt("return", next);
          case 4:
            createLifeCyclesContent = function createLifeCyclesContent() {
              var pieces = [];
              _.forIn(ir.lifeCycles, function (item, methodName) {
                if (item.type === 'JSFunction') {
                  var functionBody = item.value.match(/\{([\s\S]*)\}/)[1].trim();
                  var paramsMatch = item.value.match(/^function\s*\(([^)]*)\)/);
                  var params = paramsMatch ? paramsMatch[1] : '';
                  var arrowFunctionString = methodName + "(" + (functionBody.startsWith('(') ? '' : "(" + params + ") => ") + "{" + functionBody + "})";
                  pieces.push(arrowFunctionString);
                }
              });
              return pieces.join('\n');
            };
            createVueImport = function createVueImport() {
              var lifeCycles = [];
              _.forIn(ir.lifeCycles, function (item, methodName) {
                if (item.type === 'JSFunction') {
                  lifeCycles.push(methodName);
                }
              });
              return "import { ref," + lifeCycles.join(',') + " } from 'vue'";
            };
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.ScriptVueImp,
              content: createVueImport(),
              linkAfter: [VUE_CHUNK_NAME.ScriptStart]
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.ScriptLifeCycles,
              content: createLifeCyclesContent(),
              linkAfter: [VUE_CHUNK_NAME.ScriptVueImp, VUE_CHUNK_NAME.ScriptInitState]
            });
            return _context.abrupt("return", next);
          case 9:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return function plugin(_x) {
      return _ref.apply(this, arguments);
    };
  }();
  return plugin;
};
export default pluginFactory;

==> vue-code-generator-plugin-test-0.0.3.tgz: package/es/generator/plugins/component/vue3/lifeCycles.js <==
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _extends from "@babel/runtime/helpers/extends";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { ChunkType } from '@alilc/lowcode-code-generator';
import _ from 'lodash';
import { VUE_CHUNK_NAME, linkAfter, VUE_LIFECYCLE_HOOKS } from './const';
var pluginFactory = function pluginFactory(config) {
  var cfg = _extends({
    fileType: 'vue'
  }, config);
  var plugin = /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(pre) {
      var next, ir, createLifeCyclesContent, createVueImport;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            next = _extends({}, pre);
            ir = next.ir;
            if (ir.lifeCycles) {
              _context.next = 4;
              break;
            }
            return _context.abrupt("return", next);
          case 4:
            createLifeCyclesContent = function createLifeCyclesContent() {
              var pieces = [];
              _.forIn(ir.lifeCycles, function (item, methodName) {
                if (item.type === 'JSFunction') {
                  var functionBody = item.value.match(/\{([\s\S]*)\}/)[1].trim();
                  var paramsMatch = item.value.match(/^function\s*\(([^)]*)\)/);
                  var params = paramsMatch ? paramsMatch[1] : '';
                  var arrowFunctionString = methodName + "(" + (functionBody.startsWith('(') ? '' : "(" + params + ") => ") + "{" + functionBody + "})";
                  pieces.push(arrowFunctionString);
                }
              });
              return pieces.join('\n');
            };
            createVueImport = function createVueImport() {
              var lifeCycles = [];
              _.forIn(ir.lifeCycles, function (item, methodName) {
                if (item.type === 'JSFunction' && VUE_LIFECYCLE_HOOKS.includes(methodName)) {
                  lifeCycles.push(methodName);
                }
              });
              return "import { ref," + lifeCycles.join(',') + " } from 'vue'";
            };
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.ScriptVueImp,
              content: createVueImport(),
              linkAfter: linkAfter(VUE_CHUNK_NAME.ScriptVueImp)
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.ScriptLifeCycles,
              content: createLifeCyclesContent(),
              linkAfter: linkAfter(VUE_CHUNK_NAME.ScriptLifeCycles)
            });
            return _context.abrupt("return", next);
          case 9:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return function plugin(_x) {
      return _ref.apply(this, arguments);
    };
  }();
  return plugin;
};
export default pluginFactory;
